/**************************************************************************
 * @file        TrapSensored_Parameters_Setup.h
 * @author      MDBU Software Team
 * @brief       Parameters to be set up by the User.
 * @note        Copyright (c) 2016 Texas Instruments Incorporated.
 *              All rights reserved.
 ******************************************************************************/
// USER DEFINES
#define ALGO_ID						1       // 2 Indicates sensorless , 1 indicates sensored algorithms
#define PROD_ID                     1       // 1 Indicated AMD PL devices
#define FW_VER_MAJ                  1       // FW version major
#define FW_VER_MIN                  0       // FW version minor
#define FW_VER_PATCH                1       // FW version patch

/* System parameter setup */
#define SPEED_INPUT_SAMP_INTERVAL (127)         /* The number of PWM cycles after which change in Speed input through ADC is Sampled */
#define PWM_FACTOR (0)	          				/* 12 bit ADC result registers will be scaled to PWM period which is 10 bit  */
#define PWM_PERIOD (1000)						/* PWM Period time , With a 25Mhz clock , PWM will be generated at 25Khz*/
#define READ_VCC_PERIOD (100)					/* TIME INTERVAL AFTER WHICH VCC IS MONITORED (100ms) */
#define TIME_COUNT_1MS (25000)            		/* 1 ms timer count */
#define MIN_DUTY_CYCLE	(15)             	    /* Minimal duty cycle applied to motor */
#define MAX_DUTY_CYCLE	(1000)              	/* Maximal duty cycle applied to motor */
#define CAL_DUTY_CYCLE	(80)              	    /* Calibration duty cycle applied to motor during Hall Calibration */
#define RAMP_RATE (1)							/* Ramp rate for acceleration and deceleration of the motor speed*/
#define RAMP_RATE_DELAY (100)		        	/* How many PWM periods are between a change of the speed */
#define HALL_CALIB_CYCLES (6000)                /* Defines number of PWM cycles Motor Hall Calibration is Executed */
/* Fault handling setup */						/*ADC Max ref voltage is 3.3v ,  VCC is scaled by 0.074 internally (5/62 Ohms bridge) so that VCC ref input to ADC never cross 3.3v.*/
#define UNDER_VOLTAGE_LIMIT (8)			    /* Under Voltage set for below the specified volts - digital values are there by cal as (Limit*4095)/Full scale voltage  */
#define OVER_VOLTAGE_LIMIT	(30)     			/* Over Voltage set for above the specified volts - digital values are there by cal as (Limit*4095)/Full scale voltage */
#define MIN_POWER_SUPPLY    (5)                 /* Minimum power supply required to access the SPI , when supply voltage is below this limit gate drivers are disabled */
#define MIN_STALLDETECT_DUTY		(125)		/* Minimum Duty Cycle above which stall will be detected */
#define STALLDETECT_REV_THRESHOLD	(1)			/* Number of revolutions below which stall fault will be flagged */
#define STALLDETECT_TIMER_THRESHOLD (500)		/* Time in milli seconds above which if motor doesnt spin min revolutions specified above(STALLDETECT_REV_THRESHOLD) a stall fault is triggered */
#define AUTO_FAULT_RECOVERY_TIME (25000)      	/* Time in milli seconds after which system reinitialises itself if fault gets cleared */
#define STALL_DETECTOIN_FLAG (1)            	/* Enable motor stall fault detection*/
#define VCC_MONITOR_FLAG (1)                	/* Enable VCC Supply Voltage monitoring for fault detection */
#define MOTOR_PHASE_CURRENT_LIMIT (434)         /* Defines the max allowed motor phase current in digital counts. Motor phase current is monitored every electrical cycle , and when ever current limit is reached an OC fault is Triggered */

