/**************************************************************************
 * @file        global.c
 * @author      MDBU Software Team
 * @brief       global functions used for application
 * @note        Copyright (c) 2016 Texas Instruments Incorporated.
 *              All rights reserved.
 ******************************************************************************/
#include "global.h"



// Controller
extern SENSORED_TRAP_Obj sensoredTrapController;
extern APPLICATION_STATUS applicationStatus;
extern HOST_CONTROLLER_Obj HostController;

void EnableGateDrivers()
{
    /* Gate Drive Enable using Port 1.6 */
	//P1OUT |= BIT6;          // Enable Gate Drivers
}
void DisableGateDrivers()
{
	sensoredTrapController.CurrentDutyCycle = 0;
	SetPWMDutyCycle(sensoredTrapController.CurrentDutyCycle);
	if(sensoredTrapController.PWM_Mode == ONE_PWM_MODE)  // If six PWM mode
	{
		P2OUT &= ~(BIT4 | BIT5);                                    /* Reset bits P2.4 , P2.5  */
		P2SEL &= ~(BIT4 | BIT5);                                                                    /* Select P2.4 , P2.5 as I/O Function for Phase A*/

		/* Reset switches for phase B (LOW-HIGH)*/
		P1OUT &= ~(BIT4 | BIT5);                                    /* Reset bits P1.4 , P1.5  */
		P1SEL &= ~(BIT4 | BIT5);                                                                    /* Select P1.4 , P1.5 as I/O Function for Phase B*/

		/* Reset switches for phase C (LOW-HIGH)*/
		P1OUT &= ~(BIT2 | BIT3);                                    /* Reset bits P1.2 , P1.3  */
		P1SEL &= ~(BIT2 | BIT3);                                                                    /* Select P1.2 , P1.3 as I/O Function for Phase C*/
	}
	else
	{
		P2OUT &= ~(BIT5);
		P2SEL &= ~(BIT5);
		P1OUT &= ~BIT2  ; //  Make INLC as GPIO High to A the brakes
	}
}
/*function
 * SetPWMDutyCycle(UINT16 PWMDutyCycle)
 * Sets the PWM Duty Cycle
 * INPUT: DutyCycle Counter Value
 * */
void SetPWMDutyCycle(uint16_t PWMDutyCycle)
{
    TA0CCR1 = PWMDutyCycle;
    TA0CCR2 = PWMDutyCycle;
    TA0CCR3 = PWMDutyCycle;
    TA0CCR4 = PWMDutyCycle;
    TA2CCR1 = PWMDutyCycle;
    TA2CCR2 = PWMDutyCycle;
}
void UpdateNextCommutation()
{

    sensoredTrapController.currentHallstate = ((P2IN & BIT6) >> sensoredTrapController.ShiftForPINA)  |
                                              ((P2IN & BIT3) >> sensoredTrapController.ShiftForPINB) |
                                              ((P2IN & BIT0) << sensoredTrapController.ShiftForPINC);        /* get hall effect pin status and move */
    switch(sensoredTrapController.currentHallstate)
    {
    case 0:
        //disallowed State leads to Hall sensor Fault
        applicationStatus.previousstate = applicationStatus.currentstate;
        applicationStatus.currentstate = FAULT;
		sensoredTrapController.HallCalibComplete = FALSE;
        applicationStatus.fault = HALLSENSORINVALID;
        break;
    case 1:
        //check for Direction and sets commutation
        if(sensoredTrapController.Direction == TRUE)
        {
            PWM_SetCommutation(sensoredTrapController.currentHallstate);
        }
        else
        {
            PWM_SetCommutation(6);
        }
        //RPM count
        sensoredTrapController.RotationCount++;

        // Read Electrical Speed
        if((applicationStatus.currentstate == MOTOR_RUN) ||
           (applicationStatus.currentstate == MOTOR_RAMP_UP) ||
           (applicationStatus.currentstate == MOTOR_RAMP_DOWN) ||
		   (applicationStatus.currentstate == MOTOR_DIRECTION))
        {
          ReadSPDFDBK();
        }
        break;

    case 2:
        if(sensoredTrapController.Direction == TRUE)
        {
            PWM_SetCommutation(sensoredTrapController.currentHallstate);
        }
        else
        {
            PWM_SetCommutation(5);
        }
        break;

    case 3:
        if(sensoredTrapController.Direction == TRUE)
        {
            PWM_SetCommutation(sensoredTrapController.currentHallstate);
        }
        else
        {
            PWM_SetCommutation(4);
        }
        break;

    case 4:
        if(sensoredTrapController.Direction == TRUE)
        {
            PWM_SetCommutation(sensoredTrapController.currentHallstate);
        }
        else
        {
            PWM_SetCommutation(3);
        }
        break;

    case 5:
        if(sensoredTrapController.Direction == TRUE)
        {
            PWM_SetCommutation(sensoredTrapController.currentHallstate);
        }
        else
        {
            PWM_SetCommutation(2);
        }
        break;

    case 6:
        if(sensoredTrapController.Direction == TRUE)
        {
            PWM_SetCommutation(sensoredTrapController.currentHallstate);
        }
        else
        {
            PWM_SetCommutation(1);
        }
        break;

    case 7:
        applicationStatus.previousstate = applicationStatus.currentstate;
        applicationStatus.currentstate = FAULT;
		sensoredTrapController.HallCalibComplete = FALSE;
        applicationStatus.fault = HALLSENSORINVALID;
        break;

    default:
        break;
    }
}
/*function
 * Hall_AlignSetState(uint8_t hallState)
 * Set PWM commutation
 * INPUT: Hall state
 * */
void Hall_AlignSetState(uint8_t hallState)
{
    if (sensoredTrapController.PWM_Mode == SIX_PWM_MODE)
    {
        /* Implementing Synchronous PWM i.e. to Toggle between High side and low side of a Phase with Dead Band*/

        switch(hallState)
        {
        case 1:          /* U+ V- W- */

        	DisableGateDrivers();

            P2SEL |= BIT4 | BIT5;                                      /* Select Synchronous PWM for U phase*/
            P1OUT |= BIT4;                                             /* Set Low side of V phase */
            P1OUT |= BIT2;                                             /* Set Low side of W phase */
            break;
        case 2:         /* U+ V+ W- */

            P2SEL |= BIT4 | BIT5;                                      /* Select Synchronous PWM for U phase*/
        	P1SEL |= BIT4 | BIT5;                                      /* Select Synchronous PWM for V phase*/
            P1OUT |= BIT2;                                             /* Set Low side of W phase */
            break;
        case 3:          /* U+ V- W- */

        	P1SEL &= ~(BIT4 | BIT5);                                      /* Select Synchronous PWM for V phase*/
            P2SEL |= BIT4 | BIT5;                                      /* Select Synchronous PWM for U phase*/
            P1OUT |= BIT4;                                             /* Set Low side of V phase */
            P1OUT |= BIT2;                                             /* Set Low side of W phase */
            break;
        default:
        	break;

        }
    }
}
/*function
 * PWM_SetCommutation(uint8_t hallState)
 * Set PWM commutation
 * INPUT: Hall state
 * */
void PWM_SetCommutation(uint8_t hallState)
{
    if (sensoredTrapController.PWM_Mode == SIX_PWM_MODE)
    {

        /* Implementing Synchronous PWM i.e. to Toggle between High side and low side of a Phase with Dead Band*/

        switch(hallState)
        {
        case 1:       	  /* W-U */

            /* Reset switches for phase U (HIGH) */
            P2OUT &= ~(BIT5);                                    /* Reset bits P2.4 , P2.5  */
            P2SEL &= ~(BIT5);                                    /* Select P2.4 , P2.5 as I/O Function for Phase U*/

            /* Reset switches for phase V (LOW-HIGH)*/
            P1OUT &= ~(BIT4 | BIT5);                                    /* Reset bits P1.4 , P1.5  */
            P1SEL &= ~(BIT4 | BIT5);                                    /* Select P1.4 , P1.5 as I/O Function for Phase V*/

        	P1SEL |= BIT2 | BIT3;                                  /* Select Synchronous PWM for W phase*/
            P2OUT |= BIT4;                                         /* Set Low side of U phase */

            break;
        case 2:          /* U-V */

            /* Reset switches for phase V (LOW-HIGH)*/
            P1OUT &= ~(BIT5);                                    /* Reset bits P1.4 , P1.5  */
            P1SEL &= ~(BIT5);                                    /* Select P1.4 , P1.5 as I/O Function for Phase V*/
            /* Reset switches for phase W (LOW-HIGH)*/

            P1OUT &= ~(BIT2 | BIT3);                                    /* Reset bits P1.2 , P1.3  */
            P1SEL &= ~(BIT2 | BIT3);                                    /* Select P1.2 , P1.3 as I/O Function for Phase W*/

        	P2SEL |= BIT4 | BIT5;                                  /* Select Synchronous PWM for U phase*/
            P1OUT |= BIT4;                                         /* Set Low side of V phase */
            break;
        case 3:          /* W-V */

            /* Reset switches for phase U (LOW-HIGH) */
            P2OUT &= ~(BIT4 | BIT5);                                    /* Reset bits P2.4 , P2.5  */
            P2SEL &= ~(BIT4 | BIT5);                                    /* Select P2.4 , P2.5 as I/O Function for Phase U*/

            /* Reset switches for phase V (LOW-HIGH)*/
            P1OUT &= ~(BIT5);                                    /* Reset bits P1.4 , P1.5  */
            P1SEL &= ~(BIT5);                                    /* Select P1.4 , P1.5 as I/O Function for Phase V*/

        	P1SEL |= BIT2 | BIT3;                                   /* Select Synchronous PWM for W phase*/
            P1OUT |= BIT4;                                          /* Set Low side of V phase */
            break;
        case 4:          /* V-W */

            /* Reset switches for phase U (LOW-HIGH) */
            P2OUT &= ~(BIT4 | BIT5);                                    /* Reset bits P2.4 , P2.5  */
            P2SEL &= ~(BIT4 | BIT5);                                    /* Select P2.4 , P2.5 as I/O Function for Phase U*/

            /* Reset switches for phase W (LOW-HIGH)*/

            P1OUT &= ~(BIT3);                                    /* Reset bits P1.2 , P1.3  */
            P1SEL &= ~(BIT3);                                    /* Select P1.2 , P1.3 as I/O Function for Phase W*/

        	P1SEL |= BIT4 | BIT5;                                   /* Select Synchronous PWM for V phase*/
            P1OUT |= BIT2;                                          /* Set Low side of W phase */
            break;
        case 5:         /* V-U */

            /* Reset switches for phase U (LOW-HIGH) */
            P2OUT &= ~(BIT5);                                    /* Reset bits P2.4 , P2.5  */
            P2SEL &= ~(BIT5);                                    /* Select P2.4 , P2.5 as I/O Function for Phase U*/

            /* Reset switches for phase W (LOW-HIGH)*/

            P1OUT &= ~(BIT2 | BIT3);                                    /* Reset bits P1.2 , P1.3  */
            P1SEL &= ~(BIT2 | BIT3);                                    /* Select P1.2 , P1.3 as I/O Function for Phase W*/

        	P1SEL |= BIT4 | BIT5;                                   /* Select Synchronous PWM for V phase*/
            P2OUT |= BIT4;                                          /* Set Low side of U phase */
            break;
        case 6:         /* U-W */

            /* Reset switches for phase V (LOW-HIGH)*/
            P1OUT &= ~(BIT4 | BIT5);                                    /* Reset bits P1.4 , P1.5  */
            P1SEL &= ~(BIT4 | BIT5);                                    /* Select P1.4 , P1.5 as I/O Function for Phase V*/

            /* Reset switches for phase W (LOW-HIGH)*/
            P1OUT &= ~(BIT3);                                    /* Reset bits P1.2 , P1.3  */
            P1SEL &= ~(BIT3);                                    /* Select P1.2 , P1.3 as I/O Function for Phase W*/

        	P2SEL |= BIT4 | BIT5;                                   /* Select Synchronous PWM for of U phase*/
            P1OUT |= BIT2;                                          /* Set Low side of W phase */
            break;
        default:
        	DisableGateDrivers();

        }
    }
}

/*function
 * ReadVCC()
 * Triggers and internal VCC ADC sample and evaluates for over or under voltage fault
 * */
void ReadVCC()
{
    ADC12CTL0 |= ADC12SC;                   // Start conversion
    ADC12IE = ADC12IE0;                     // Enable Interrupt after last conversion
}

/*function
 * ReadCurrentshunt()
 * Reads CSA value and triggers OC faults for Motor current greater than Set Limit
 * */
void ReadCurrentShunt()
{
    ADC12CTL0 |= ADC12SC;                   // Start conversion
    ADC12IE = ADC12IE1;                     // Enable Interrupt after last conversion
}

/*function
 * ReadSPDFDBK()
 * Reads Electrical Speed of the motor
 * */
void ReadSPDFDBK()
{
	/* RPM count & Speed measurement of 16 Bit resolution */

	if(!sensoredTrapController.TimerOverflowFlag) /* A count of three indicates timer A1 ticked for 0x010000 clocks */
	{
		sensoredTrapController.SPDFdbk = TA1R;    /* Generate the speed count = The max value 0xFFFF represents the least possible speed measurement which is 625K / 0xFFFF = 9.52Hz as  timer 1 is run at 625KHz */
	}
	sensoredTrapController.TimerOverflowFlag = 0 ; /* Reset the Interrupt flag */
	TA1R = 0x0000;				                   /* Reset the timer count */
}

/*function
 * drv83xx_getGPIO(unsigned char gpioPort, unsigned char gpioNum)
 * Device specific Get GPIO function
 * */
unsigned char drv83xx_getGPIO(unsigned char gpioPort, unsigned char gpioNum)
{
    if (gpioPort == 0x01)
    {
        if ((gpioNum & P1IN) == 0)
        {
          if (gpioNum == EN_DRV)
          {
            HostController.EnabledGateDrivers = GATE_DISABLED;
          }
            return 0;
        }
        else
        {
          if (gpioNum == EN_DRV)
          {
            HostController.EnabledGateDrivers = GATE_ENABLED;
          }
            return 1;
        }
    }
    else if (gpioPort == 0x02)
    {
        if ((gpioNum & P2IN) == 0)
            return 0;
        else
            return 1;
    }
    else
    {
        // do nothing
        return 0;
    }
}

/*function
 * drv83xx_getGPIO(unsigned char gpioPort, unsigned char gpioNum, unsigned char gpioVal)
 * Device specific Set GPIO function
 * */
void drv83xx_setGPIO(unsigned char gpioPort, unsigned char gpioNum, unsigned char gpioVal)
{
	    if (gpioPort == 0x01)
	    {
	        if (gpioVal == 0)
	        {
	            P1OUT &= ~gpioNum;
              if (gpioNum == EN_DRV)
              {
                HostController.EnabledGateDrivers = GATE_DISABLED;
				sensoredTrapController.GateToggleFaultDetect = TRUE;     // Set the Gate toggle fault detect for 10ms
				sensoredTrapController.GateToggleCounter = 0;
              }
	        }
	        else
	        {
	            P1OUT |= gpioNum;
              if (gpioNum == EN_DRV)
              {

                HostController.EnabledGateDrivers = GATE_ENABLED;
				sensoredTrapController.GateToggleFaultDetect = TRUE;     // Set the Gate toggle fault detect for 10ms
				sensoredTrapController.GateToggleCounter = 0;
              }
	        }
	    }
	    else if (gpioPort == 0x02)
	    {
	        if (gpioVal == 0)
	            P2OUT &= ~gpioNum;
	        else
	            P2OUT |= gpioNum;
	    }
	    else
	    {
	        // do nothing
	    }

}

/*function
 * drv83xx_StartMotor()
 * Device specific Start Motor function
 * */
void drv83xx_StartMotor()
{
	HostController.StartStopMotor = START_MOTOR;
}

/*function
 * drv83xx_StartMotor()
 * Device specific Stop Motor function
 * */
void drv83xx_StopMotor()
{
	HostController.StartStopMotor = STOP_MOTOR;
}


/*function
 * drv83xx_registerRead(unsigned char address)
 * Device specific register read funtion
 * */
unsigned int drv83xx_registerRead(unsigned char address)
{
    unsigned int regValue;

    /* Read the value from the device*/


    /* Cache the value in the firmware */
	if (applicationStatus.fault != POWER_SUPPLY)
	{
		 regValue = drv8343_SPI_Read(address);
		 drv83xx_regToCache(address, regValue);
    }
	else
	{
		regValue = drv83xx_cachetoReg(address);
	}
    return regValue;
}

/*function
 * drv83xx_registerWrite()
 * Device specific register write funtion
 * */
void drv83xx_registerWrite(unsigned char address, unsigned int value)
{

	drv83xx_regToCache(address, value);

	/* Cache the value in the firmware */
	if (applicationStatus.fault != POWER_SUPPLY)
	{
		/* Write the value to the device */
		drv8343_SPI_Write(address, value);
	}
}

/*function
 * drv83xx_getMtrParam(unsigned char num)
 * Returns device specific motor parameter value based on the passed parameter
 * number
 * */
unsigned long drv83xx_getMtrParam(unsigned char num)
{
	switch(num)
	{
		case MTR_PARAM_DIR:
			return sensoredTrapController.Direction;
		case MTR_PARAM_SPEED:
			return sensoredTrapController.TargetDutyCycle;
		case MTR_PARAM_DEVICE_ID:
			return sensoredTrapController.DeviceID;
		case MTR_MIN_DUTY_CYCLE:
			return sensoredTrapController.MINDutyCycle;
		case MTR_MAX_DUTY_CYCLE:
			return sensoredTrapController.MAXDutyCycle;
		case MTR_RAMP_RATE_DELAY:
			return sensoredTrapController.Accelerationdivider;
		case MTR_UNDER_VOLTAGE_LIMIT:
			return sensoredTrapController.underVoltageLimit;
		case MTR_OVER_VOLTAGE_LIMIT:
			return sensoredTrapController.overVoltageLimit;
		case MTR_MIN_STALLDETECT_DUTY:
			return sensoredTrapController.minStallDetectDuty;
		case MTR_STALLDETECT_REV_THRESHOLD:
			return sensoredTrapController.stallDetectRevThreshold;
		case MTR_STALLDETECT_TIMER_THRESHOLD:
			return sensoredTrapController.stallDetectTimerThreshold;
		case MTR_AUTO_FAULT_RECOVERY_TIME:
			return sensoredTrapController.autoFaultRecoveryTime;
		case MTR_MOTOR_PHASE_CURRENT_LIMIT:
			return sensoredTrapController.MotorPhaseCurrentLimit;
		case MTR_FAULT_STATUS:
			return applicationStatus.fault;
		case MTR_PARAM_ELEC_SPEED:
			return sensoredTrapController.SPDFdbk;
        case MTR_PARAM_PWM_FREQ:
            return sensoredTrapController.PWMPeriod;
        case MTR_START_STOP_MOTOR:
			return HostController.StartStopMotor;
        case MTR_HALL_CALIBRATE:
			return HostController.CalibrateHall;
        case MTR_CALIBRATE_DUTY_CYCLE:
			return sensoredTrapController.CALDutyCycle;
        case MTR_CALIBRATION_CYCLES:
        	return sensoredTrapController.HallCalibrationCycles;
        case MTR_AUTO_CALIBRATION:
			return sensoredTrapController.AutoHallCalib;
        case DEVICE_FULL_SCALE_VOLTAGE:
        	return FULL_SCALE_VOLTAGE;
        case DEVICE_CLEAR_FAULTS:
        	return FALSE;
		default:
	        return(0);
	}
}

/*function
 * drv83xx_setMtrParam(unsigned char num, unsigned long value)
 * Sets the device specific motor parameter value based on the passed parameter
 * number
 * */
void drv83xx_setMtrParam(unsigned char num, unsigned long value)
{
	switch(num)
	{
		case MTR_PARAM_DIR:
            if(sensoredTrapController.Direction_flag == TRUE)
            {
              if(sensoredTrapController.Direction == value)
              {
                sensoredTrapController.Direction_flag = FALSE;

                if (HostController.StartStopMotor == START_MOTOR)
                {
                  applicationStatus.previousstate = applicationStatus.currentstate;
                  applicationStatus.currentstate = MOTOR_RAMP_UP;
                }
              }
            }
            else
            {
              if(sensoredTrapController.Direction != value)
              {
                sensoredTrapController.Direction_flag = TRUE;

                applicationStatus.previousstate = applicationStatus.currentstate;
                applicationStatus.currentstate = MOTOR_DIRECTION;
              }
            }
            if(sensoredTrapController.PWM_Mode == ONE_PWM_MODE)
			{
				if(sensoredTrapController.Direction == TRUE )
				{
					P1OUT |= BIT3;                  // Set the direction to high using INHC on drv83xxx EVM
				}
				else
				{
					P1OUT &= ~BIT3;                  // Set the direction to low using INHC on drv83xxx EVM
				}
			}
			break;
		case MTR_PARAM_SPEED:
			sensoredTrapController.TargetDutyCycle = value;
			break;
		case MTR_MIN_DUTY_CYCLE:
			sensoredTrapController.MINDutyCycle = value;
			break;
		case MTR_MAX_DUTY_CYCLE:
			sensoredTrapController.MAXDutyCycle = value;
			break;
		case MTR_RAMP_RATE_DELAY:
			sensoredTrapController.Accelerationdivider = value;
			break;
		case MTR_UNDER_VOLTAGE_LIMIT:
			sensoredTrapController.underVoltageLimit = value;
			break;
		case MTR_OVER_VOLTAGE_LIMIT:
			sensoredTrapController.overVoltageLimit = value;
			break;
		case MTR_MIN_STALLDETECT_DUTY:
			sensoredTrapController.minStallDetectDuty = value;
			break;
		case MTR_STALLDETECT_REV_THRESHOLD:
			sensoredTrapController.stallDetectRevThreshold = value;
			break;
		case MTR_STALLDETECT_TIMER_THRESHOLD:
			sensoredTrapController.stallDetectTimerThreshold = value;
			break;
		case MTR_AUTO_FAULT_RECOVERY_TIME:
			sensoredTrapController.autoFaultRecoveryTime = value;
			break;
		case MTR_MOTOR_PHASE_CURRENT_LIMIT:
			sensoredTrapController.MotorPhaseCurrentLimit = value;
			break;
        case MTR_PARAM_PWM_FREQ:
            sensoredTrapController.PWMPeriod = value;
			sensoredTrapController.Counter_1M_Second = (25000 / sensoredTrapController.PWMPeriod);
			sensoredTrapController.Counter_1M_Second *= 1000;
			TimerA0_Init();             // Timer A0 Initialization to generate 4 PWM's for switches
            TimerA2_Init();             // Timer A2 Initialization to generate 2 PWM's for switches
            break;
        case MTR_HALL_CALIBRATE:
			HostController.CalibrateHall = value;
			if(HostController.CalibrateHall)
			{
				sensoredTrapController.CurrentDutyCycle = 0;
				SetPWMDutyCycle(sensoredTrapController.CurrentDutyCycle);
				sensoredTrapController.HallAlignInterruptFlag = FALSE;
				sensoredTrapController.HallAlignStartFlag = TRUE;
				sensoredTrapController.HallAligncounter = 0;
				sensoredTrapController.HallAlignState = 1;
				Hall_AlignSetState(sensoredTrapController.HallAlignState);
			}
			else
			{
    			DisableGateDrivers();
				applicationStatus.previousstate = applicationStatus.currentstate;                  /* Move to System Idle state and initialize Motor variables*/
				applicationStatus.currentstate = SYSTEM_IDLE;
				sensoredTrapController.HallAlignStartFlag = FALSE;
			}
        	break;
        case MTR_CALIBRATE_DUTY_CYCLE:
			sensoredTrapController.CALDutyCycle = value;
			break;
        case MTR_CALIBRATION_CYCLES:
        	sensoredTrapController.HallCalibrationCycles = value;
        	break;
        case MTR_AUTO_CALIBRATION:
        	sensoredTrapController.AutoHallCalib =value;
        	break;
		case DEVICE_CLEAR_FAULTS:
			if(applicationStatus.currentstate == FAULT)
			{
				sensoredTrapController.RestartDelay = sensoredTrapController.autoFaultRecoveryTime; // Set the Restart delay to AutoFault recovery Time value to trigger clear faults routine
			}
			break;
        default:
	        break;
	}
}

/*function
 * drv83xx_setCtrlType(unsigned char value)
 * Sets the Control Type
 * */
void drv83xx_setCtrlType(unsigned char value)
{
	PWM_Init();
	DisableGateDrivers();
    if(sensoredTrapController.PWM_Mode == SIX_PWM_MODE) // If 6x PWM mode configure the Mode pin to pull down
    {
        P4SEL &= ~BIT3;  // Select the GPIO functionality of the pin
    	P4DIR |= BIT3;   // Set the pin as Output
        P4OUT &= ~BIT3;  // Set the pin logic low
    }
    else // If 1x PWM mode configure mode pin to High Impedence state
    {
        P4SEL &= ~BIT3;	 // Select the GPIO functionality of the pin
    	P4DIR &= ~BIT3;  // Set the pin as Input
    	P4REN &= ~BIT3;  // Diable the the Pull up/ pull down set the pin to high impedence
    }
	if(sensoredTrapController.SPIVariant == TRUE)                  // Only if the device is "S" Variant
	{
		/* 1XPWM */
		if (sensoredTrapController.PWM_Mode == ONE_PWM_MODE)
		{
			drv83xx_set_One_PWM_Mode();
		}
		else if (sensoredTrapController.PWM_Mode == SIX_PWM_MODE)
		{
			drv83xx_set_Six_PWM_Mode();
		}
	}

}

/*function
 * drv83xx_setCtrlType(unsigned char value)
 * Gets the Control Type
 * */
unsigned char drv83xx_getCtrlType(void)
{
	return sensoredTrapController.PWM_Mode;
}
